@@ -73,7 +73,7 @@ if TYPE_CHECKING:
 
 @dataclass
 class CommandParameter:
-    """Represents a application command parameter.
+    """Represents an application command parameter.
 
     Attributes
     -----------
@@ -441,7 +441,7 @@ class EnumNameTransformer(Transformer):
             raise TypeError(f'enum.Enum requires at least two values.')
 
         self._enum: Any = enum
-        self._choices = [Choice(name=v.name, value=v.value) for v in values]
+        self._choices = [Choice(name=v.name, value=v.name) for v in values]
 
     @property
     def _error_display_name(self) -> str:
@@ -459,6 +459,23 @@ class EnumNameTransformer(Transformer):
         return self._enum[value]
 
 
+class InlineTransformer(Transformer):
+    def __init__(self, annotation: Any) -> None:
+        super().__init__()
+        self.annotation: Any = annotation
+
+    @property
+    def _error_display_name(self) -> str:
+        return self.annotation.__name__
+
+    @property
+    def type(self) -> AppCommandOptionType:
+        return AppCommandOptionType.string
+
+    async def transform(self, interaction: Interaction, value: Any) -> Any:
+        return await self.annotation.transform(interaction, value)
+
+
 if TYPE_CHECKING:
     from typing_extensions import Annotated as Transform
     from typing_extensions import Annotated as Range
@@ -716,6 +733,17 @@ def get_supported_annotation(
         if annotation is Choice:
             raise TypeError(f'Choice requires a type argument of int, str, or float')
 
+        # Check if a transform @classmethod is given to the class
+        # These flatten into simple "inline" transformers with implicit strings
+        transform_classmethod = annotation.__dict__.get('transform', None)
+        if isinstance(transform_classmethod, classmethod):
+            params = inspect.signature(transform_classmethod.__func__).parameters
+            if len(params) != 3:
+                raise TypeError(f'Inline transformer with transform classmethod requires 3 parameters')
+            if not inspect.iscoroutinefunction(transform_classmethod.__func__):
+                raise TypeError(f'Inline transformer with transform classmethod must be a coroutine')
+            return (InlineTransformer(annotation), MISSING, False)
+
     # Check if there's an origin
     origin = getattr(annotation, '__origin__', None)
     if origin is Literal:
@@ -810,6 +838,6 @@ def annotation_to_parameter(annotation: Any, parameter: inspect.Parameter) -> Co
     if inner.autocomplete.__func__ is not Transformer.autocomplete:
         from .commands import _validate_auto_complete_callback
 
-        result.autocomplete = _validate_auto_complete_callback(inner.autocomplete, skip_binding=True)
+        result.autocomplete = _validate_auto_complete_callback(inner.autocomplete)
 
     return result
